docs.rs failed to build blueprint-client-eigenlayer-0.2.0-alpha.12
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
blueprint-client-eigenlayer-0.2.0-alpha.10
blueprint-client-eigenlayer
EigenLayer-specific client implementation for Blueprint services.
What it includes
- EigenLayer client bindings/wrappers.
- EigenLayer-focused error types.
When to use
Use this crate when your blueprint integrates with EigenLayer contract/operator flows.